<?php
global $smsadvert_settings, $wpml_activo;

//Control de tabulación
$tab = 1;

//WPML
if ( $smsadvert_settings ) {
    $mensajes   = [
        'mensaje_pedido',
        'mensaje_fallido',
        'mensaje_recibido',
        'mensaje_procesando',
        'mensaje_completado',
        'mensaje_devuelto',
        'mensaje_cancelado',
        'mensaje_nota'
    ];
    
    if ( function_exists( 'icl_register_string' ) || !$wpml_activo ) { //Versión anterior a la 3.2
        foreach( $mensajes as $mensaje ) {
            if ( isset( $smsadvert_settings[ $mensaje ] ) ) {
                $$mensaje		= ( $wpml_activo ) ? icl_translate( 'smsadvert', $mensaje, $smsadvert_settings[ $mensaje ] ) : $smsadvert_settings[ $mensaje ];
            }
        }
    } else if ( $wpml_activo ) { //Versión 3.2 o superior
        foreach( $mensajes as $mensaje ) {
            if ( isset( $smsadvert_settings[ $mensaje ] ) ) {
                $$mensaje		= apply_filters( 'wpml_translate_single_string', $smsadvert_settings[ $mensaje ], 'smsadvert', $mensaje );
            }
        }
    }
}

//Listado de proveedores SMS
$listado_de_proveedores = [ 
	"smsadvert"         => "smsadvert"
];
asort( $listado_de_proveedores, SORT_NATURAL | SORT_FLAG_CASE ); //Ordena alfabeticamente los proveedores

//Campos necesarios para cada proveedor
$campos_de_proveedores = [
	"smsadvert"			=> [
		"smsadvert_key"						=> __( 'smsadvert API token', 'woocommerce-order-status-sms' ),
		"smsadvert_sendAsShort"				=> __( 'Primary channel', 'woocommerce-order-status-sms' ),
		"smsadvert_failover"				=> __( 'Secondary channel', 'woocommerce-order-status-sms' ),
	],
];

//Opciones de campos de selección de los proveedores
$opciones_de_proveedores = [
	"smsadvert_sendAsShort"	=> [
		true					=> __( "smsadvert network", 'woocommerce-order-status-sms' ), 
		false					=> __( "own devices", 'woocommerce-order-status-sms' ), 
	],
    "smsadvert_failover"  => [
		false					=> __( "none", 'woocommerce-order-status-sms' ), 
		true					=> __( "smsadvert network", 'woocommerce-order-status-sms' ), 
 	],
];

//Listado de estados de pedidos
$listado_de_estados				= wc_get_order_statuses();
$listado_de_estados_temporal	= [];
$estados_originales				= [ 
	'pending',
	'failed',
	'on-hold',
	'processing',
	'completed',
	'refunded',
	'cancelled',
];
foreach( $listado_de_estados as $clave => $estado ) {
	$nombre_de_estado = str_replace( "wc-", "", $clave );
	if ( !in_array( $nombre_de_estado, $estados_originales ) ) {
		$listado_de_estados_temporal[ $estado ] = $nombre_de_estado;
	}
}
$listado_de_estados = $listado_de_estados_temporal;

//Listado de mensajes personalizados
$listado_de_mensajes = [
	'todos'					=> __( 'All messages', 'woocommerce-order-status-sms' ),
	'mensaje_pedido'		=> __( 'Owner custom message', 'woocommerce-order-status-sms' ),
	'mensaje_pendiente'		=> __( 'Order pending custom message', 'woocommerce-order-status-sms' ),
	'mensaje_fallido'		=> __( 'Order failed custom message', 'woocommerce-order-status-sms' ),
	'mensaje_recibido'		=> __( 'Order on-hold custom message', 'woocommerce-order-status-sms' ),
	'mensaje_procesando'	=> __( 'Order processing custom message', 'woocommerce-order-status-sms' ),
	'mensaje_completado'	=> __( 'Order completed custom message', 'woocommerce-order-status-sms' ),
	'mensaje_devuelto'		=> __( 'Order refunded custom message', 'woocommerce-order-status-sms' ),
	'mensaje_cancelado'		=> __( 'Order cancelled custom message', 'woocommerce-order-status-sms' ),
	'mensaje_nota'			=> __( 'Notes custom message', 'woocommerce-order-status-sms' ),
];

/*
Pinta el campo select con el listado de proveedores
*/
function smsadvert_listado_de_proveedores( $listado_de_proveedores ) {
	global $smsadvert_settings;
	
	foreach ( $listado_de_proveedores as $valor => $proveedor ) {
		$chequea = ( isset( $smsadvert_settings[ 'servicio' ] ) && $smsadvert_settings[ 'servicio' ] == $valor ) ? ' selected="selected"' : '';
		echo '<option value="' . $valor . '"' . $chequea . '>' . $proveedor . '</option>' . PHP_EOL;
	}
}

/*
Pinta los campos de los proveedores
*/
function smsadvert_campos_de_proveedores( $listado_de_proveedores, $campos_de_proveedores, $opciones_de_proveedores ) {
	global $smsadvert_settings, $tab;
	
	foreach ( $listado_de_proveedores as $valor => $proveedor ) {
		foreach ( $campos_de_proveedores[$valor] as $valor_campo => $campo ) {
			if ( array_key_exists( $valor_campo, $opciones_de_proveedores ) ) { //Campo select
				echo '
  <tr valign="top" class="' . $valor . '"><!-- ' . $proveedor . ' -->
	<th scope="row" class="titledesc"> <label for="smsadvert_settings[' . $valor_campo . ']">' .ucfirst( $campo ) . ':' . '
	  <span class="woocommerce-help-tip" data-tip="' . sprintf( __( 'The %s for your account in %s', 'woocommerce-order-status-sms' ), $campo, $proveedor ) . '"></span></label></th>
	<td class="forminp forminp-number"><select class="wc-enhanced-select" id="smsadvert_settings[' . $valor_campo . ']" name="smsadvert_settings[' . $valor_campo . ']" tabindex="' . $tab++ . '">
				';
				foreach ( $opciones_de_proveedores[$valor_campo] as $valor_opcion => $opcion ) {
					$chequea = ( isset( $smsadvert_settings[$valor_campo] ) && $smsadvert_settings[$valor_campo] == $valor_opcion ) ? ' selected="selected"' : '';
					echo '<option value="' . $valor_opcion . '"' . $chequea . '>' . $opcion . '</option>' . PHP_EOL;
				}
				echo '          </select></td>
  </tr>
				';
			} else { //Campo input
				echo '
  <tr valign="top" class="' . $valor . '"><!-- ' . $proveedor . ' -->
	<th scope="row" class="titledesc"> <label for="smsadvert_settings[' . $valor_campo . ']">' . ucfirst( $campo ) . ':' . '
	  <span class="woocommerce-help-tip" data-tip="' . sprintf( __( 'The %s for your account in %s', 'woocommerce-order-status-sms' ), $campo, $proveedor ) . '"></span></label></th>
	<td class="forminp forminp-number"><input type="text" id="smsadvert_settings[' . $valor_campo . ']" name="smsadvert_settings[' . $valor_campo . ']" size="50" value="' . ( isset( $smsadvert_settings[$valor_campo] ) ? $smsadvert_settings[$valor_campo] : '' ) . '" tabindex="' . $tab++ . '" /></td>
  </tr>
				';
			}
		}
	}
}

/*
Pinta los campos del formulario de envío
*/
function smsadvert_campos_de_envio() {
	global $smsadvert_settings;

	$pais					= new WC_Countries();
	$campos					= $pais->get_address_fields( $pais->get_base_country(), 'shipping_' ); //Campos ordinarios
	$campos_personalizados	= apply_filters( 'woocommerce_checkout_fields', [] );
	if ( isset( $campos_personalizados[ 'shipping' ] ) ) {
		$campos += $campos_personalizados[ 'shipping' ];
	}
	foreach ( $campos as $valor => $campo ) {
		$chequea = ( isset( $smsadvert_settings[ 'campo_envio' ] ) && $smsadvert_settings[ 'campo_envio' ] == $valor ) ? ' selected="selected"' : '';
		if ( isset( $campo[ 'label' ] ) ) {
			echo '<option value="' . $valor . '"' . $chequea . '>' . $campo[ 'label' ] . '</option>' . PHP_EOL;
		}
	}
}

/*
Pinta el campo select con el listado de estados de pedido
*/
function smsadvert_listado_de_estados( $listado_de_estados ) {
	global $smsadvert_settings;

	foreach( $listado_de_estados as $nombre_de_estado => $estado ) {
		$chequea = '';
		if ( isset( $smsadvert_settings[ 'estados_personalizados' ] ) ) {
			foreach ( $smsadvert_settings[ 'estados_personalizados' ] as $estado_personalizado ) {
				if ( $estado_personalizado == $estado ) {
					$chequea = ' selected="selected"';
				}
			}
		}
		echo '<option value="' . $estado . '"' . $chequea . '>' . $nombre_de_estado . '</option>' . PHP_EOL;
	}
}

/*
Pinta el campo select con el listado de mensajes personalizados
*/
function smsadvert_listado_de_mensajes( $listado_de_mensajes ) {
	global $smsadvert_settings;
	
	$chequeado = false;
	foreach ( $listado_de_mensajes as $valor => $mensaje ) {
		if ( isset( $smsadvert_settings[ 'mensajes' ] ) && in_array( $valor, $smsadvert_settings[ 'mensajes' ] ) ) {
			$chequea	= ' selected="selected"';
			$chequeado	= true;
		} else {
			$chequea	= '';
		}
		$texto = ( !isset( $smsadvert_settings[ 'mensajes' ] ) && $valor == 'todos' && !$chequeado ) ? ' selected="selected"' : '';
		echo '<option value="' . $valor . '"' . $chequea . $texto . '>' . $mensaje . '</option>' . PHP_EOL;
	}
}


/*
Pinta los campos de mensajes
*/
function smsadvert_campo_de_mensaje_personalizado( $campo, $campo_cliente, $listado_de_mensajes ) {
    global $tab;
    
    //Listado de mensajes personalizados
    $listado_de_mensajes_personalizados = [
        'mensaje_pedido'		=> __( 'Order No. %s received on ', 'woocommerce-order-status-sms' ),
        'mensaje_pendiente'		=> __( 'Thank you for shopping with us! Your order No. %s is now: ', 'woocommerce-order-status-sms' ),
        'mensaje_fallido'		=> __( 'Thank you for shopping with us! Your order No. %s is now: ', 'woocommerce-order-status-sms' ),
        'mensaje_recibido'		=> __( 'Your order No. %s is received on %s. Thank you for shopping with us!', 'woocommerce-order-status-sms' ),
        'mensaje_procesando'	=> __( 'Thank you for shopping with us! Your order No. %s is now: ', 'woocommerce-order-status-sms' ),
        'mensaje_completado'	=> __( 'Thank you for shopping with us! Your order No. %s is now: ', 'woocommerce-order-status-sms' ),
        'mensaje_devuelto'		=> __( 'Thank you for shopping with us! Your order No. %s is now: ', 'woocommerce-order-status-sms' ),
        'mensaje_cancelado'		=> __( 'Thank you for shopping with us! Your order No. %s is now: ', 'woocommerce-order-status-sms' ),
        'mensaje_nota'			=> __( 'A note has just been added to your order No. %s: ', 'woocommerce-order-status-sms' ),
    ];

    //Listado de textos personalizados
    $listado_de_textos_personalizados = [
        'mensaje_pendiente'		=> __( 'Pending', 'woocommerce-order-status-sms' ),
        'mensaje_fallido'		=> __( 'Failed', 'woocommerce-order-status-sms' ),
        'mensaje_procesando'	=> __( 'Processing', 'woocommerce-order-status-sms' ),
        'mensaje_completado'	=> __( 'Completed', 'woocommerce-order-status-sms' ),
        'mensaje_devuelto'		=> __( 'Refunded', 'woocommerce-order-status-sms' ),
        'mensaje_cancelado'		=> __( 'Cancelled', 'woocommerce-order-status-sms' ),
    ];

    if ( $campo == 'mensaje_pedido'  ) {
        $texto  = stripcslashes( !empty( $campo_cliente ) ? $campo_cliente : sprintf( __( $listado_de_mensajes_personalizados[ $campo ], 'woocommerce-order-status-sms' ), "%id%" ) . "%shop_name%" . "." );
    } elseif ( $campo == 'mensaje_recibido'  ) {
        $texto  = stripcslashes( !empty( $campo_cliente ) ? $campo_cliente : sprintf( __( $listado_de_mensajes_personalizados[ $campo ], 'woocommerce-order-status-sms' ), "%id%", "%shop_name%" ) );
    } elseif ( $campo == 'mensaje_nota'  ) {
        $texto  = stripcslashes( !empty( $campo_cliente ) ? $campo_cliente : sprintf( __( $listado_de_mensajes_personalizados[ $campo ], 'woocommerce-order-status-sms' ), "%id%" ) . "%note%" );
    } else {
        $texto  = stripcslashes( !empty( $campo_cliente ) ? $campo_cliente : sprintf( __( $listado_de_mensajes_personalizados[ $campo ], 'woocommerce-order-status-sms' ), "%id%" ) . __( $listado_de_textos_personalizados[ $campo ], 'woocommerce-order-status-sms' ) . "." );
    }
    
    echo'
        <tr valign="top" class="' . $campo . '">
            <th scope="row" class="titledesc">
                <label for="smsadvert_settings[' . $campo . ']">
                    ' . __( $listado_de_mensajes[ $campo ], 'woocommerce-order-status-sms' ) .':
                    <span class="woocommerce-help-tip" data-tip="'. __( "You can customize your message. Remember that you can use this variables: %id%, %order_key%, %billing_first_name%, %billing_last_name%, %billing_company%, %billing_address_1%, %billing_address_2%, %billing_city%, %billing_postcode%, %billing_country%, %billing_state%, %billing_email%, %billing_phone%, %shipping_first_name%, %shipping_last_name%, %shipping_company%, %shipping_address_1%, %shipping_address_2%, %shipping_city%, %shipping_postcode%, %shipping_country%, %shipping_state%, %shipping_method%, %shipping_method_title%, %payment_method%, %payment_method_title%, %order_discount%, %cart_discount%, %order_tax%, %order_shipping%, %order_shipping_tax%, %order_total%, %status%, %prices_include_tax%, %tax_display_cart%, %display_totals_ex_tax%, %display_cart_ex_tax%, %order_date%, %modified_date%, %customer_message%, %customer_note%, %post_status%, %shop_name%, %order_product% and %note%.", "woocommerce-order-status-sms" ) . '"></span>
                </label>
            </th>
            <td class="forminp forminp-number"><textarea id="smsadvert_settings[' . $campo . ']" name="smsadvert_settings[' . $campo . ']" cols="50" rows="5" tabindex="' . $tab++ . '">' .$texto . '</textarea>
            </td>
        </tr>';
}
