<?php
/*
Plugin Name: WooCommerce Order Status SMS
Version: 1.1
Plugin URI: https://smsadvert.io/
Description: Send custom SMS notifications when the status of an order changes.
Author URI: https://smsadvert.io/
Author: smsadvert.io
Requires at least: 3.8
Tested up to: 5.6
WC requires at least: 2.1
WC tested up to: 4.4

Text Domain: woocommerce-order-status-sms
Domain Path: /languages

@package WooCommerce Order Status SMS
@category Core
@author smsadvert.io
*/

//Igual no deberías poder abrirme
defined( 'ABSPATH' ) || exit;

//Definimos constantes
define( 'BASENAME_smsadvert', plugin_basename( __FILE__ ) );

//Funciones generales de APG
include_once( 'includes/admin/funciones-apg.php' );

//¿Está activo WooCommerce?
include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
if ( is_plugin_active( 'woocommerce/woocommerce.php' ) || is_network_only_plugin( 'woocommerce/woocommerce.php' ) ) {
	//Cargamos funciones necesarias
	include_once( 'includes/admin/funciones.php' );

	//Comprobamos si está instalado y activo WPML
	$wpml_activo = function_exists( 'icl_object_id' );
	
	//Actualiza las traducciones de los mensajes SMS
	function apg_registra_wpml( $smsadvert_settings ) {
		global $wpml_activo;
		
        $textos = [
            'mensaje_pedido',
            'mensaje_pendiente',
            'mensaje_fallido',
            'mensaje_recibido',
            'mensaje_procesando',
            'mensaje_completado',
            'mensaje_devuelto',
            'mensaje_cancelado',
            'mensaje_nota',
        ];
        
		//Registramos los textos en WPML
		if ( $wpml_activo && function_exists( 'icl_register_string' ) ) {
            foreach( $textos as $texto ) {
                icl_register_string( 'smsadvert', $texto, $smsadvert_settings[ $texto ] );
            }
		} else if ( $wpml_activo ) {
            foreach( $textos as $texto ) {
                do_action( 'wpml_register_single_string', 'smsadvert', $texto, $smsadvert_settings[ $texto ] );
            }
		}
	}
	
	//Inicializamos las traducciones y los proveedores
	function smsadvert_inicializacion() {
		global $smsadvert_settings;

		apg_registra_wpml( $smsadvert_settings );
	}
	add_action( 'init', 'smsadvert_inicializacion' );

	//Pinta el formulario de configuración
	function smsadvert_tab() {
		include( 'includes/admin/funciones-formulario.php' );
		include( 'includes/formulario.php' );
	}

	//Añade en el menú a WooCommerce
	function smsadvert_admin_menu() {
		add_submenu_page( 'woocommerce', __( 'Order Status SMS', 'woocommerce-order-status-sms' ),  __( 'Order Status SMS', 'woocommerce-order-status-sms' ) , 'manage_woocommerce', 'smsadvert', 'smsadvert_tab' );
	}
	add_action( 'admin_menu', 'smsadvert_admin_menu', 15 );

	//Carga los scripts y CSS de WooCommerce
	function smsadvert_screen_id( $woocommerce_screen_ids ) {
		$woocommerce_screen_ids[] = 'woocommerce_page_smsadvert';

		return $woocommerce_screen_ids;
	}
	add_filter( 'woocommerce_screen_ids', 'smsadvert_screen_id' );

	//Registra las opciones
	function smsadvert_registra_opciones() {
		global $smsadvert_settings;
	
		register_setting( 'smsadvert_settings_group', 'smsadvert_settings', 'smsadvert_update' );
		$smsadvert_settings = get_option( 'smsadvert_settings' );

		if ( isset( $smsadvert_settings[ 'estados_personalizados' ] ) && !empty( $smsadvert_settings[ 'estados_personalizados' ] ) ) { //Comprueba la existencia de estados personalizados
			foreach ( $smsadvert_settings[ 'estados_personalizados' ] as $estado ) {
				add_action( "woocommerce_order_status_{$estado}", 'smsadvert_procesa_estados', 10 );
			}
		}
	}
	add_action( 'admin_init', 'smsadvert_registra_opciones' );
	
	function smsadvert_update( $smsadvert_settings ) {
		apg_registra_wpml( $smsadvert_settings );
		
		return $smsadvert_settings;
	}

	//Procesa el SMS
	function smsadvert_procesa_estados( $pedido, $notificacion = false ) {
		global $smsadvert_settings, $wpml_activo;
		
		$numero_de_pedido	= $pedido;
		$pedido				= new WC_Order( $numero_de_pedido );
		$estado				= is_callable( [ $pedido, 'get_status' ] ) ? $pedido->get_status() : $pedido->status;

		//Comprobamos si se tiene que enviar el mensaje o no
		if ( isset( $smsadvert_settings[ 'mensajes' ] ) ) {
			if ( $estado == 'on-hold' && !array_intersect( [ "todos", "mensaje_pedido", "mensaje_recibido" ], $smsadvert_settings[ 'mensajes' ] ) ) {
				return;
			} else if ( $estado == 'pending' && !array_intersect( [ "todos", "mensaje_pendiente" ], $smsadvert_settings[ 'mensajes' ] ) ) {
				return;
			} else if ( $estado == 'failed' && !array_intersect( [ "todos", "mensaje_fallido" ], $smsadvert_settings[ 'mensajes' ] ) ) {
				return;
			} else if ( $estado == 'processing' && !array_intersect( [ "todos", "mensaje_pedido", "mensaje_procesando" ], $smsadvert_settings[ 'mensajes' ] ) ) {
				return;
			} else if ( $estado == 'completed' && !array_intersect( [ "todos", "mensaje_completado" ], $smsadvert_settings[ 'mensajes' ] ) ) {
				return;
			} else if ( $estado == 'refunded' && !array_intersect( [ "todos", "mensaje_devuelto" ], $smsadvert_settings[ 'mensajes' ] ) ) {
				return;
			} else if ( $estado == 'cancelled' && !array_intersect( [ "todos", "mensaje_cancelado" ], $smsadvert_settings[ 'mensajes' ] ) ) {
				return;
			}
		} else {
			return;
		}
        
		//Permitir que otros plugins impidan que se envíe el SMS
		if ( !apply_filters( 'smsadvert_send_message', true, $pedido ) ) {
			return;
		}

		//Recoge datos del formulario de facturación
		$billing_country		= is_callable( [ $pedido, 'get_billing_country' ] ) ? $pedido->get_billing_country() : $pedido->billing_country;
		$billing_phone			= is_callable( [ $pedido, 'get_billing_phone' ] ) ? $pedido->get_billing_phone() : $pedido->billing_phone;
		$shipping_country		= is_callable( [ $pedido, 'get_shipping_country' ] ) ? $pedido->get_shipping_country() : $pedido->shipping_country;
		$campo_envio			= get_post_meta( $numero_de_pedido, $smsadvert_settings[ 'campo_envio' ], false );
		$campo_envio			= ( isset( $campo_envio[0] ) ) ? $campo_envio[0] : '';
		$telefono				= smsadvert_procesa_el_telefono( $pedido, $billing_phone, $smsadvert_settings[ 'servicio' ] );
		$telefono_envio			= smsadvert_procesa_el_telefono( $pedido, $campo_envio, $smsadvert_settings[ 'servicio' ], false, true );
		$enviar_envio			= ( !empty( $telefono_envio ) && $telefono != $telefono_envio && isset( $smsadvert_settings[ 'envio' ] ) && $smsadvert_settings[ 'envio' ] == 1 ) ? true : false;
		$internacional			= ( isset( $billing_country ) && ( WC()->countries->get_base_country() != $billing_country ) ) ? true : false;
		$internacional_envio	= ( isset( $shipping_country ) && ( WC()->countries->get_base_country() != $shipping_country ) ) ? true : false;
        
		//Teléfono propietario
		if ( strpos( $smsadvert_settings[ 'telefono' ], "|" ) ) {
			$administradores = explode( "|", $smsadvert_settings[ 'telefono' ] ); //Existe más de uno
		}
		if ( isset( $administradores ) ) {
			foreach( $administradores as $administrador ) {
				$telefono_propietario[]	= smsadvert_procesa_el_telefono( $pedido, $administrador, $smsadvert_settings[ 'servicio' ], true );
			}
		} else {
			$telefono_propietario = smsadvert_procesa_el_telefono( $pedido, $smsadvert_settings[ 'telefono' ], $smsadvert_settings[ 'servicio' ], true );	
		}

		//WPML
		if ( function_exists( 'icl_register_string' ) || !$wpml_activo ) { //Versión anterior a la 3.2
			$mensaje_pedido		= ( $wpml_activo ) ? icl_translate( 'smsadvert', 'mensaje_pedido', $smsadvert_settings[ 'mensaje_pedido' ] ) : $smsadvert_settings[ 'mensaje_pedido' ];
			$mensaje_pendiente	= ( $wpml_activo ) ? icl_translate( 'smsadvert', 'mensaje_pendiente', $smsadvert_settings[ 'mensaje_pendiente' ] ) : $smsadvert_settings[ 'mensaje_pendiente' ];
			$mensaje_fallido	= ( $wpml_activo ) ? icl_translate( 'smsadvert', 'mensaje_fallido', $smsadvert_settings[ 'mensaje_fallido' ] ) : $smsadvert_settings[ 'mensaje_fallido' ];
			$mensaje_recibido	= ( $wpml_activo ) ? icl_translate( 'smsadvert', 'mensaje_recibido', $smsadvert_settings[ 'mensaje_recibido' ] ) : $smsadvert_settings[ 'mensaje_recibido' ];
			$mensaje_procesando	= ( $wpml_activo ) ? icl_translate( 'smsadvert', 'mensaje_procesando', $smsadvert_settings[ 'mensaje_procesando' ] ) : $smsadvert_settings[ 'mensaje_procesando' ];
			$mensaje_completado	= ( $wpml_activo ) ? icl_translate( 'smsadvert', 'mensaje_completado', $smsadvert_settings[ 'mensaje_completado' ] ) : $smsadvert_settings[ 'mensaje_completado' ];
			$mensaje_devuelto	= ( $wpml_activo ) ? icl_translate( 'smsadvert', 'mensaje_devuelto', $smsadvert_settings[ 'mensaje_devuelto' ] ) : $smsadvert_settings[ 'mensaje_devuelto' ];
			$mensaje_cancelado	= ( $wpml_activo ) ? icl_translate( 'smsadvert', 'mensaje_cancelado', $smsadvert_settings[ 'mensaje_cancelado' ] ) : $smsadvert_settings[ 'mensaje_cancelado' ];
		} else if ( $wpml_activo ) { //Versión 3.2 o superior
			$mensaje_pedido		= apply_filters( 'wpml_translate_single_string', $smsadvert_settings[ 'mensaje_pedido' ], 'smsadvert', 'mensaje_pedido' );
			$mensaje_pendiente	= apply_filters( 'wpml_translate_single_string', $smsadvert_settings[ 'mensaje_pendiente' ], 'smsadvert', 'mensaje_pendiente' );
			$mensaje_fallido	= apply_filters( 'wpml_translate_single_string', $smsadvert_settings[ 'mensaje_fallido' ], 'smsadvert', 'mensaje_fallido' );
			$mensaje_recibido	= apply_filters( 'wpml_translate_single_string', $smsadvert_settings[ 'mensaje_recibido' ], 'smsadvert', 'mensaje_recibido' );
			$mensaje_procesando	= apply_filters( 'wpml_translate_single_string', $smsadvert_settings[ 'mensaje_procesando' ], 'smsadvert', 'mensaje_procesando' );
			$mensaje_completado	= apply_filters( 'wpml_translate_single_string', $smsadvert_settings[ 'mensaje_completado' ], 'smsadvert', 'mensaje_completado' );
			$mensaje_devuelto	= apply_filters( 'wpml_translate_single_string', $smsadvert_settings[ 'mensaje_devuelto' ], 'smsadvert', 'mensaje_devuelto' );
			$mensaje_cancelado	= apply_filters( 'wpml_translate_single_string', $smsadvert_settings[ 'mensaje_cancelado' ], 'smsadvert', 'mensaje_cancelado' );
		}
		
		//Cargamos los proveedores SMS
		include_once( 'includes/admin/proveedores.php' );
        
		//Envía el SMS
		switch( $estado ) {
			case 'on-hold': //Pedido en espera
				if ( !!array_intersect( [ "todos", "mensaje_pedido" ], $smsadvert_settings[ 'mensajes' ] ) && isset( $smsadvert_settings[ 'notificacion' ] ) && $smsadvert_settings[ 'notificacion' ] == 1 && !$notificacion ) {
					if ( !is_array( $telefono_propietario ) ) {
						smsadvert_envia_sms( $smsadvert_settings, $telefono_propietario, smsadvert_procesa_variables( $mensaje_pedido, $pedido, $smsadvert_settings[ 'variables' ] ) ); //Mensaje para el propietario
					} else {
						foreach( $telefono_propietario as $administrador ) {
							smsadvert_envia_sms( $smsadvert_settings, $administrador, smsadvert_procesa_variables( $mensaje_pedido, $pedido, $smsadvert_settings[ 'variables' ] ) ); //Mensaje para los propietarios
						}
					}
				}
						
				if ( !!array_intersect( [ "todos", "mensaje_recibido" ], $smsadvert_settings[ 'mensajes' ] ) ) {
					//Limpia el temporizador para pedidos recibidos
					wp_clear_scheduled_hook( 'smsadvert_ejecuta_el_temporizador' );

                    //Retardo para pedidos recibidos
 					if ( isset( $smsadvert_settings[ 'retardo' ] ) && $smsadvert_settings[ 'retardo' ] > 0 && ( ! intval( get_post_meta( $numero_de_pedido, 'smsadvert_retardo_enviado', true ) ) == 1 ) ) {
 						wp_schedule_single_event( time() + ( absint( $smsadvert_settings[ 'retardo' ] ) * 60 ), 'smsadvert_ejecuta_el_retraso', [ $numero_de_pedido ] );
 						update_post_meta( $numero_de_pedido, 'smsadvert_retardo_enviado', -1 );
 					} else { //Envío normal
 						$mensaje = smsadvert_procesa_variables( $mensaje_recibido, $pedido, $smsadvert_settings[ 'variables' ] ); //Mensaje para el cliente
 					}
                    
					//Temporizador para pedidos recibidos
					if ( isset( $smsadvert_settings[ 'temporizador' ] ) && $smsadvert_settings[ 'temporizador' ] > 0 ) {
						wp_schedule_single_event( time() + ( absint( $smsadvert_settings[ 'temporizador' ] ) * 60 * 60 ), 'smsadvert_ejecuta_el_temporizador' );
					}
				}
                
				break;
			case 'pending': //Pedido pendiente
				if ( !!array_intersect( [ "todos", "mensaje_pendiente" ], $smsadvert_settings[ 'mensajes' ] ) ) {
					$mensaje = smsadvert_procesa_variables( $mensaje_pendiente, $pedido, $smsadvert_settings[ 'variables' ] );
				}
                
				break;
			case 'failed': //Pedido fallido
				if ( !!array_intersect( [ "todos", "mensaje_fallido" ], $smsadvert_settings[ 'mensajes' ] ) ) {
					$mensaje = smsadvert_procesa_variables( $mensaje_fallido, $pedido, $smsadvert_settings[ 'variables' ] );
				}
                
				break;
			case 'processing': //Pedido procesando
				if ( !!array_intersect( [ "todos", "mensaje_pedido" ], $smsadvert_settings[ 'mensajes' ] ) && isset( $smsadvert_settings[ 'notificacion' ] ) && $smsadvert_settings[ 'notificacion' ] == 1 && $notificacion ) {
					if ( !is_array( $telefono_propietario ) ) {
						smsadvert_envia_sms( $smsadvert_settings, $telefono_propietario, smsadvert_procesa_variables( $mensaje_pedido, $pedido, $smsadvert_settings[ 'variables' ] ) ); //Mensaje para el propietario
					} else {
						foreach( $telefono_propietario as $administrador ) {
							smsadvert_envia_sms( $smsadvert_settings, $administrador, smsadvert_procesa_variables( $mensaje_pedido, $pedido, $smsadvert_settings[ 'variables' ] ) ); //Mensaje para los propietarios
						}
					}
				}
                
				if ( !!array_intersect( [ "todos", "mensaje_procesando" ], $smsadvert_settings[ 'mensajes' ] ) ) {
					$mensaje = smsadvert_procesa_variables( $mensaje_procesando, $pedido, $smsadvert_settings[ 'variables' ] );
				}
                
				break;
			case 'completed': //Pedido completado
				if ( !!array_intersect( [ "todos", "mensaje_completado" ], $smsadvert_settings[ 'mensajes' ] ) ) {
					$mensaje = smsadvert_procesa_variables( $mensaje_completado, $pedido, $smsadvert_settings[ 'variables' ] );
				}
                
				break;
			case 'refunded': //Pedido devuelto
				if ( !!array_intersect( [ "todos", "mensaje_devuelto" ], $smsadvert_settings[ 'mensajes' ] ) ) {
					$mensaje = smsadvert_procesa_variables( $mensaje_devuelto, $pedido, $smsadvert_settings[ 'variables' ] );
				}
                
				break;
			case 'cancelled': //Pedido cancelado
				if ( !!array_intersect( [ "todos", "mensaje_cancelado" ], $smsadvert_settings[ 'mensajes' ] ) ) {
					$mensaje = smsadvert_procesa_variables( $mensaje_cancelado, $pedido, $smsadvert_settings[ 'variables' ] );
				}
                
				break;
			default: //Pedido con estado personalizado
				$mensaje = smsadvert_procesa_variables( $smsadvert_settings[$estado], $pedido, $smsadvert_settings[ 'variables' ] );
		}    
        
		if ( isset( $mensaje ) && ( !$internacional || ( isset( $smsadvert_settings[ 'internacional' ] ) && $smsadvert_settings[ 'internacional' ] == 1 ) ) && !$notificacion ) {
			if ( !is_array( $telefono ) ) {
				smsadvert_envia_sms( $smsadvert_settings, $telefono, $mensaje ); //Mensaje para el teléfono de facturación
			} else {
				foreach( $telefono as $cliente ) {
					smsadvert_envia_sms( $smsadvert_settings, $cliente, $mensaje ); //Mensaje para los teléfonos recibidos
				}
			}
			if ( $enviar_envio ) {
				smsadvert_envia_sms( $smsadvert_settings, $telefono_envio, $mensaje ); //Mensaje para el teléfono de envío
			}
		}
	}
	add_action( 'woocommerce_order_status_on-hold', 'smsadvert_procesa_estados', 10 ); //Funciona cuando el pedido es marcado como recibido
	add_action( 'woocommerce_order_status_pending', 'smsadvert_procesa_estados', 10 ); //Funciona cuando el pedido es marcado como pendiente
	add_action( 'woocommerce_order_status_failed', 'smsadvert_procesa_estados', 10 ); //Funciona cuando el pedido es marcado como fallido
	add_action( 'woocommerce_order_status_processing', 'smsadvert_procesa_estados', 10 ); //Funciona cuando el pedido es marcado como procesando
	add_action( 'woocommerce_order_status_completed', 'smsadvert_procesa_estados', 10 ); //Funciona cuando el pedido es marcado como completo
	add_action( 'woocommerce_order_status_refunded', 'smsadvert_procesa_estados', 10 ); //Funciona cuando el pedido es marcado como devuelto
	add_action( 'woocommerce_order_status_cancelled', 'smsadvert_procesa_estados', 10 ); //Funciona cuando el pedido es marcado como cancelado

	function smsadvert_notificacion( $pedido ) {
		smsadvert_procesa_estados( $pedido, true );
	}
	add_action( 'woocommerce_order_status_pending_to_processing_notification', 'smsadvert_notificacion', 10 ); //Funciona cuando el pedido es marcado directamente como procesando
	
    //Retraso
 	function smsadvert_retardo( $numero_de_pedido ) {
 		global $smsadvert_settings;
        
 		if ( $pedido = wc_get_order( intval( $numero_de_pedido ) ) ) {
 			$retraso_enviado    = get_post_meta( $numero_de_pedido, 'smsadvert_retardo_enviado', true );
 			$estado             = is_callable( [ $pedido, 'get_status' ] ) ? $pedido->get_status() : $pedido->status;
 			if ( intval( $retraso_enviado ) == -1 ) {		 			//Solo enviamos si no ha cambiado de estado
 				update_post_meta( $numero_de_pedido, 'smsadvert_retardo_enviado', 1 );		 			
                if ( $estado == 'on-hold' ) {
                    smsadvert_procesa_estados( $numero_de_pedido, false );		 				
                    $retraso_enviado    = get_post_meta( $numero_de_pedido, 'smsadvert_retardo_enviado', true );
                    if ( intval( $retraso_enviado ) == -1 ) {
                        update_post_meta( $numero_de_pedido, 'smsadvert_retardo_enviado', 1 );
                        smsadvert_procesa_estados( $numero_de_pedido, false );
                    }
                }
            }
        }
    }
 	add_action( 'smsadvert_ejecuta_el_retraso', 'smsadvert_retardo' );
    
	//Temporizador
	function smsadvert_temporizador() {
		global $smsadvert_settings;
		
		$pedidos = wc_get_orders( [
			'limit'			=> -1,
			'date_created'	=> '<' . ( time() - ( absint( $smsadvert_settings[ 'temporizador' ] ) * 60 * 60 ) - 1 ),
			'status'		=> 'on-hold',
		] );

		if ( $pedidos ) {
			foreach ( $pedidos as $pedido ) {
				smsadvert_procesa_estados( is_callable( [ $pedido, 'get_id' ] ) ? $pedido->get_id() : $pedido->id, false );
			}
		}
	}
	add_action( 'smsadvert_ejecuta_el_temporizador', 'smsadvert_temporizador' );

	//Envía las notas de cliente por SMS
	function smsadvert_procesa_notas( $datos ) {
		global $smsadvert_settings, $wpml_activo;
		
		//Comprobamos si se tiene que enviar el mensaje
		if ( isset( $smsadvert_settings[ 'mensajes' ] ) && !array_intersect( [ "todos", "mensaje_nota" ], $smsadvert_settings[ 'mensajes' ] ) ) {
			return;
		}
	
		//Pedido
		$numero_de_pedido		= $datos[ 'order_id' ];
		$pedido					= new WC_Order( $numero_de_pedido );
		//Recoge datos del formulario de facturación
		$billing_country		= is_callable( [ $pedido, 'get_billing_country' ] ) ? $pedido->get_billing_country() : $pedido->billing_country;
		$billing_phone			= is_callable( [ $pedido, 'get_billing_phone' ] ) ? $pedido->get_billing_phone() : $pedido->billing_phone;
		$shipping_country		= is_callable( [ $pedido, 'get_shipping_country' ] ) ? $pedido->get_shipping_country() : $pedido->shipping_country;	
		$campo_envio			= get_post_meta( $numero_de_pedido, $smsadvert_settings[ 'campo_envio' ], false );
		$campo_envio			= ( isset( $campo_envio[0] ) ) ? $campo_envio[0] : '';
		$telefono				= smsadvert_procesa_el_telefono( $pedido, $billing_phone, $smsadvert_settings[ 'servicio' ] );
		$telefono_envio			= smsadvert_procesa_el_telefono( $pedido, $campo_envio, $smsadvert_settings[ 'servicio' ], false, true );
		$enviar_envio			= ( isset( $smsadvert_settings[ 'envio' ] ) && $telefono != $telefono_envio && $smsadvert_settings[ 'envio' ] == 1 ) ? true : false;
		$internacional			= ( $billing_country && ( WC()->countries->get_base_country() != $billing_country ) ) ? true : false;
		$internacional_envio	= ( $shipping_country && ( WC()->countries->get_base_country() != $shipping_country ) ) ? true : false;
		//Recoge datos del formulario de facturación
		$billing_country		= is_callable( [ $pedido, 'get_billing_country' ] ) ? $pedido->get_billing_country() : $pedido->billing_country;
		$billing_phone			= is_callable( [ $pedido, 'get_billing_phone' ] ) ? $pedido->get_billing_phone() : $pedido->billing_phone;
		$shipping_country		= is_callable( [ $pedido, 'get_shipping_country' ] ) ? $pedido->get_shipping_country() : $pedido->shipping_country;
		$campo_envio			= get_post_meta( $numero_de_pedido, $smsadvert_settings[ 'campo_envio' ], false );
		$campo_envio			= ( isset( $campo_envio[0] ) ) ? $campo_envio[0] : '';
		$telefono				= smsadvert_procesa_el_telefono( $pedido, $billing_phone, $smsadvert_settings[ 'servicio' ] );
		$telefono_envio			= smsadvert_procesa_el_telefono( $pedido, $campo_envio, $smsadvert_settings[ 'servicio' ], false, true );
		$enviar_envio			= ( $telefono != $telefono_envio && isset( $smsadvert_settings[ 'envio' ] ) && $smsadvert_settings[ 'envio' ] == 1 ) ? true : false;
		$internacional			= ( $billing_country && ( WC()->countries->get_base_country() != $billing_country ) ) ? true : false;
		$internacional_envio	= ( $shipping_country && ( WC()->countries->get_base_country() != $shipping_country ) ) ? true : false;

		//WPML
		if ( function_exists( 'icl_register_string' ) || !$wpml_activo ) { //Versión anterior a la 3.2
			$mensaje_nota		= ( $wpml_activo ) ? icl_translate( 'smsadvert', 'mensaje_nota', $smsadvert_settings[ 'mensaje_nota' ] ) : $smsadvert_settings[ 'mensaje_nota' ];
		} else if ( $wpml_activo ) { //Versión 3.2 o superior
			$mensaje_nota		= apply_filters( 'wpml_translate_single_string', $smsadvert_settings[ 'mensaje_nota' ], 'smsadvert', 'mensaje_nota' );
		}
		
		//Cargamos los proveedores SMS
		include_once( 'includes/admin/proveedores.php' );		
		//Envía el SMS
		if ( !$internacional || ( isset( $smsadvert_settings[ 'internacional' ] ) && $smsadvert_settings[ 'internacional' ] == 1 ) ) {
			if ( !is_array( $telefono ) ) {
				smsadvert_envia_sms( $smsadvert_settings, $telefono, smsadvert_procesa_variables( $mensaje_nota, $pedido, $smsadvert_settings[ 'variables' ], wptexturize( $datos[ 'customer_note' ] ) ) ); //Mensaje para el teléfono de facturación
			} else {
				foreach( $telefono as $cliente ) {
					smsadvert_envia_sms( $smsadvert_settings, $cliente, smsadvert_procesa_variables( $mensaje_nota, $pedido, $smsadvert_settings[ 'variables' ], wptexturize( $datos[ 'customer_note' ] ) ) ); //Mensaje para los teléfonos recibidos
				}
			}
			if ( $enviar_envio ) {
				smsadvert_envia_sms( $smsadvert_settings, $telefono_envio, smsadvert_procesa_variables( $mensaje_nota, $pedido, $smsadvert_settings[ 'variables' ], wptexturize( $datos[ 'customer_note' ] ) ) ); //Mensaje para el teléfono de envío
			}
		}
	}
	add_action( 'woocommerce_new_customer_note', 'smsadvert_procesa_notas', 10 );
} else {
	add_action( 'admin_notices', 'smsadvert_requiere_wc' );
}

//Muestra el mensaje de activación de WooCommerce y desactiva el plugin
function smsadvert_requiere_wc() {
	global $smsadvert;
		
	echo '<div class="error fade" id="message"><h3>' . $smsadvert[ 'plugin' ] . '</h3><h4>' . __( "This plugin require WooCommerce active to run!", 'woocommerce-order-status-sms' ) . '</h4></div>';
	deactivate_plugins( BASENAME_smsadvert );
}

//Eliminamos todo rastro del plugin al desinstalarlo
function smsadvert_desinstalar() {
	delete_option( 'smsadvert_settings' );
	delete_transient( 'smsadvert_plugin' );
}
register_uninstall_hook( __FILE__, 'smsadvert_desinstalar' );
